AttributeDomain

Enum AttributeDomain 

pub enum AttributeDomain {
    Position,
    Corner,
}
The domain of the attribute, i.e. whether it is defined on the position or corner.

Variants



Position

The attribute is defined on the position attribute, i.e. i’th element in the attribute is attached to the i’th position in the mesh.



Corner

The attribute is defined on the corner attribute, i.e. i’th element in the attribute is attached to the i’th corner in the mesh.

Implementations

Source

impl AttributeDomain

pub fn write_to<W: ByteWriter>(&self, writer: &mut W)

Writes the id of the attribute domain to the writer.

pub fn read_from<R: ByteReader>(reader: &mut R) -> Result<Self, Err>

Reads the attribute domain from the reader.