Structs
- BitReader
- BitWriter
- Functional
Byte Reader - A special byte reader that is provided by draco-oxide that allows users to build custom byte readers using a cloure.
- Functional
Byte Writer - A special byte writer that is provided by draco-oxide that allows users to build custom byte writers using a cloure.
Enums
Traits
- Byte
Reader - Byte
Writer - A trait that defines what a byte writer should implement. Users can implement this for any custom buffer type, and draco-oxide is able to write the output to it.
- Reverse
Byte Reader