pub struct MaybeInitAttributeBuffer { /* private fields */ }Implementations
Sourceimpl MaybeInitAttributeBuffer
impl MaybeInitAttributeBuffer
Sourcepub fn new(
len: usize,
component_type: ComponentDataType,
num_components: usize,
) -> Self
pub fn new( len: usize, component_type: ComponentDataType, num_components: usize, ) -> Self
Creates a new attribute buffer with the given component type and number of components. This allocates memory for the buffer, but does not initialize it.
Sourcepub fn as_slice_unchecked<Data, const N: usize>(&self) -> &[Data]
pub fn as_slice_unchecked<Data, const N: usize>(&self) -> &[Data]
Returns a slice of all the values in the buffer casted to the static type Data.
Safety: Callers must know exactly which part of resulting slice is valid.
Dereferencing the uninitialized part of the slice is undefined behavior.
Moreover, ‘num_components * component_type.size()’ must equal ‘std::mem::size_of::()’.
pub fn write<Data, const N: usize>(&mut self, idx: usize, data: Data)
Sourcepub fn write_type_unchecked<Data, const N: usize>(
&mut self,
idx: usize,
data: Data,
)
pub fn write_type_unchecked<Data, const N: usize>( &mut self, idx: usize, data: Data, )
Safety: The caller must ensure that the type of the data matches the type of the buffer. Furthermore, the index must be within the bounds of the buffer.
Sourcepub fn get_component_type(&self) -> ComponentDataType
pub fn get_component_type(&self) -> ComponentDataType
Returns the component type of the attribute.
Sourcepub fn get_num_components(&self) -> usize
pub fn get_num_components(&self) -> usize
Returns the number of components.